@@ -10,12 +10,12 @@
 ## and appearing in the file LICENSE.GPL included in the packaging of
 ## this file.  Please review the following information to ensure GNU
 ## General Public Licensing requirements will be met:
-## http://www.trolltech.com/products/qt/opensource.html
+## https://www.qt.io/download-open-source
 ##
 ## If you are unsure which license is appropriate for your use, please
 ## review the following information:
-## http://www.trolltech.com/products/qt/licensing.html or contact the
-## sales department at sales@trolltech.com.
+## https://www.qt.io/licensing/ or contact the
+## sales department at https://www.qt.io/contact-us/sales-contact-request/?hsLang=en
 ##
 ## This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ## WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,7 +26,10 @@ There are several variations of python ports for this script floating
 around, it seemed easier to me to maintain one for myself
 """
 
-import sip
+try:
+    from PyQt5 import sip
+except ImportError:
+    import sip
 from qt import QObject, Qt, QAbstractItemModel, QModelIndex
 from qt import QPersistentModelIndex, QFont, QColor, QSize
 from common import isAlive
@@ -310,7 +313,7 @@ class ModelTest(QObject):
         self.parent()
         self.data()
 
-    def rowsAboutToBeInserted(self, parent, start, dummyEnd):
+    def rowsAboutToBeInserted(self, parent, start, unusedEnd):
         """
         Store what is about to be inserted to make sure it actually happens
         """
@@ -455,7 +458,7 @@ class ModelTest(QObject):
                 # assert( index.model() == self.model )
                 # This raises an error that is not part of the qbzr code.
                 # see
-                # http://www.opensubscriber.com/message/pyqt@riverbankcomputing.com/10335500.html
+                # https://www.riverbankcomputing.com/pipermail/pyqt/2011-February/029300.html
                 assert(index.row() == row)
                 assert(index.column() == column)
                 # While you can technically return a QVariant usually this is a sign
