@@ -3,19 +3,8 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 The DBPasswordChecker is based on an example from the book
 Twisted Network Programming Essentials by Abe Fettig, 2006
@@ -28,12 +17,11 @@ import sys
 import os
 import logging
 import datetime
-from signal import signal, SIGABRT, SIGINT, SIGTERM
 
 from zope.interface import implementer
 
 
-def cleanExit(*dummyArgs):
+def cleanExit(*unusedArgs): # pylint: disable=unused-argument
     """we want to cleanly close sqlite3 files"""
     if Debug.quit:
         logDebug('cleanExit')
@@ -56,14 +44,8 @@ def cleanExit(*dummyArgs):
     except ReactorNotRunning:
         pass
 
-signal(SIGABRT, cleanExit)
-signal(SIGINT, cleanExit)
-signal(SIGTERM, cleanExit)
-if os.name != 'nt':
-    from signal import SIGHUP, SIGQUIT
-    signal(SIGHUP, cleanExit)
-    signal(SIGQUIT, cleanExit)
-
+from common import handleSignals
+handleSignals(cleanExit)
 
 from common import Options, Internal, Debug
 Internal.isServer = True
@@ -114,7 +96,7 @@ class DBPasswordChecker:
                 pass
         query = Query(
             'select id, password from player where name=?', (cred.username,))
-        if not len(query.records):
+        if not query.records:
             template = 'Wrong username: %1'
             if Debug.connections:
                 logDebug(i18n(template, cred.username))
@@ -165,6 +147,7 @@ class MJServer:
             except (pb.DeadReferenceError, pb.PBConnectionLost):
                 user.mind = None
                 self.logout(user)
+        return None
 
     @staticmethod
     def __stopAfterLastDisconnect():
@@ -209,17 +192,17 @@ class MJServer:
         """send tables to user. If tables is None, he gets all new tables and those
         suspended tables he was sitting on"""
         if tables is None:
-            tables = list(x for x in self.tables.values()
-                          if not x.running and (not x.suspendedAt or x.hasName(user.name)))
-        if len(tables):
-            data = list(x.asSimpleList() for x in tables)
+            tables = [
+                x for x in self.tables.values()
+                if not x.running and (not x.suspendedAt or x.hasName(user.name))]
+        if tables:
+            data = [x.asSimpleList() for x in tables]
             if Debug.table:
                 logDebug(
                     'sending %d tables to %s: %s' %
                     (len(tables), user.name, data))
             return self.callRemote(user, 'newTables', data)
-        else:
-            return succeed([])
+        return succeed([])
 
     def _lookupTable(self, tableid):
         """return table by id or raise exception"""
@@ -249,15 +232,14 @@ class MJServer:
                                      tableId, self.tables[tableId])))
         if Ruleset.hashIsKnown(ruleset):
             return self.__newTable(None, user, ruleset, playOpen, autoPlay, wantedGame, tableId)
-        else:
-            return self.callRemote(user, 'needRuleset', ruleset).addCallback(
-                gotRuleset).addCallback(
-                    self.__newTable, user, ruleset, playOpen, autoPlay, wantedGame, tableId)
+        return self.callRemote(user, 'needRuleset', ruleset).addCallback(
+            gotRuleset).addCallback(
+                self.__newTable, user, ruleset, playOpen, autoPlay, wantedGame, tableId)
 
-    def __newTable(self, dummy, user, ruleset,
+    def __newTable(self, unused, user, ruleset,
                    playOpen, autoPlay, wantedGame, tableId=None):
         """now we know the ruleset"""
-        def sent(dummy):
+        def sent(unused):
             """new table sent to user who created it"""
             return table.tableid
         table = ServerTable(
@@ -300,7 +282,7 @@ class MJServer:
             if Debug.table:
                 logDebug('Table %s: All seats taken, starting' % table)
 
-            def startTable(dummy):
+            def startTable(unused):
                 """now all players know about our join"""
                 table.readyForGameStart(table.owner)
             block.callback(startTable)
@@ -310,9 +292,9 @@ class MJServer:
 
     def tablesWith(self, user):
         """table ids with user, except table 'without'"""
-        return list(x.tableid for x in self.tables.values() if user in x.users)
+        return [x.tableid for x in self.tables.values() if user in x.users]
 
-    def leaveTable(self, user, tableid, message=None, *args):
+    def leaveTable(self, user, tableid, message, *args):
         """user leaves table. If no human user is left on a new table, remove it"""
         if tableid in self.tables:
             table = self.tables[tableid]
@@ -337,7 +319,7 @@ class MJServer:
         """try to start the game"""
         return self._lookupTable(tableid).readyForGameStart(user)
 
-    def removeTable(self, table, reason, message=None, *args):
+    def removeTable(self, table, reason, message, *args):
         """remove a table"""
         assert reason in ('silent', 'tableRemoved', 'gameOver', 'abort')
         # HumanClient implements methods remote_tableRemoved etc.
